@@ -3,6 +3,8 @@ import time
 
 import epaper
 
+from raspberry_epaper.epd_core import EPDCore
+
 
 class EPD:
     @staticmethod
@@ -11,34 +13,32 @@ class EPD:
 
     def __init__(self, device):
         logging.debug("Initialize:{}".format(device))
+        self.device = device
         self.epdLib = epaper.epaper(device)
-        self.epd = self.epdLib.EPD()
+        self.epd_core = EPDCore(self.device, self.epdLib)
 
     def clear(self):
         logging.debug("Clear")
-        self.epd.init()
-        self.epd.Clear()
+        self.epd_core.init()
+        self.epd_core.Clear()
         time.sleep(1)
 
-    def display(self, blackImage, colorImage=None):
+    def display(self, image1, image2=None):
         logging.debug("Display")
-        if colorImage:
-            self.epd.display(
-                self.epd.getbuffer(blackImage), self.epd.getbuffer(colorImage)
-            )
-        else:
-            self.epd.display(self.epd.getbuffer(blackImage))
+        self.epd_core.display(image1, image2)
 
     def sleep(self):
         logging.debug("Sleep")
-        self.epd.sleep()
+        self.epd_core.sleep()
 
     def exit(self):
         logging.debug("Exit")
         self.epdLib.epdconfig.module_exit()
 
+    @property
     def width(self):
-        return self.epd.width
+        return self.epd_core.width
 
+    @property
     def height(self):
-        return self.epd.height
+        return self.epd_core.height
